==> ktorrent-20.12.3.tar.xz: ktorrent-20.12.3/libktcore/groups/allgroup.cpp <==
/***************************************************************************
 *   Copyright (C) 2007 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#include <KLocalizedString>
#include "allgroup.h"

namespace kt
{

AllGroup::AllGroup() : Group(i18n("All Torrents"), MIXED_GROUP, QStringLiteral("/all"))
{
    setIconByName(QStringLiteral("folder"));
}


AllGroup::~AllGroup()
{}


bool AllGroup::isMember(TorrentInterface* tor)
{
    return tor != 0;
}

}

==> ktorrent-21.04.3.tar.xz: ktorrent-21.04.3/libktcore/groups/allgroup.cpp <==
/***************************************************************************
 *   Copyright (C) 2007 by Joris Guisson                                   *
 *   joris.guisson@gmail.com                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
 ***************************************************************************/

#include "allgroup.h"
#include <KLocalizedString>

namespace kt
{
AllGroup::AllGroup()
    : Group(i18n("All Torrents"), MIXED_GROUP, QStringLiteral("/all"))
{
    setIconByName(QStringLiteral("folder"));
}

AllGroup::~AllGroup()
{
}

bool AllGroup::isMember(TorrentInterface *tor)
{
    return tor != 0;
}

}
